@@ -1,9 +1,10 @@
 from typing import Dict
 
+from asn1tools.codecs import oer, constraints_checker
+
 from asn1editor.controller.Controller import Controller
 from asn1editor.view.AbstractView import ListView, AbstractView
 from asn1editor.view.AbstractViewFactory import AbstractViewFactory
-from asn1tools.codecs import oer, constraints_checker
 
 
 class ListInstanceFactory:
@@ -18,21 +19,13 @@ class ListInstanceFactory:
     def create(self, instance: int, parent: Controller):
         from asn1editor.ViewControllerFactory import ViewControllerFactory
 
-        self._view_factory.freeze()
-
         view_factory = ViewControllerFactory(self._view_factory)
         self._type.name = f'Element {instance}'
         self.content_views[instance] = view_factory.create_view_and_controller(self._type, self._checker, parent)
 
         self._list_view.add(self.content_views[instance])
 
-        self._view_factory.update()
-
-        self._view_factory.thaw()
-
     def destroy(self, instance: int):
         self._list_view.remove(self.content_views[instance])
 
-        self._view_factory.update()
-
         del self.content_views[instance]
